% function [x,CF]=Proximal_Descent_Accelerated(x0,A,AT,y,tau,sigma,nit,verbose)
%
% This function solves
% min ||x||_1 + sigma/2 ||AT x-y||_2^2
% using a proximal gradient descent.
% - Note : it is assumed that ||A||=1.
%
% INPUT:
% - x0 : initial guess.
% - A and AT : function handles to A and its transpose.
% - y : data.
% - tau : descent step (should be in ]0,2/L], where L=||A||^2).
% - sigma : data fidelity.
% - nit : iteration number.
% - verbose : optional (default=0) will display the result every verbose
% iteration.
%
% OUTPUT :
% - x : solution.
% - CF : cost function.
%
% Developer : Pierre Weiss
function [x,CF]=Proximal_Descent_Accelerated(x0,A,AT,y,tau,sigma,nit,verbose)

if nargin<=5
    verbose=0;
end

x_=x0;
z=x0;
CF=zeros(nit,1);
for k=1:nit
    ATz=AT(z);
    CF(k) = sum(abs(z(:))) + sigma/2 * norm(ATz(:)-y(:))^2;
    grad=sigma*A(ATz-y);
    x=z-tau*grad;
    x=shrink(x,tau);
    z=x+(k-1)/(k+2)*(x-x_);
    x_=x;
    
    
    if verbose
        if (mod(k-1,verbose)==0)
            figure(100);
            colormap gray;
            imagesc(real(x));
            title(sprintf('Iteration %i/%i -- Acelerated Proximal Gradient Descent',k,nit));
        end
    end
    
end